@@ -1,26 +1,29 @@
-/* GDA library
- * Copyright (C) 1998 - 2008 The GNOME Foundation.
+/*
+ * Copyright (C) 2000 Reinhard Müller <reinhard@src.gnome.org>
+ * Copyright (C) 2000 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2001 Carlos Perell Marn <carlos@gnome-db.org>
+ * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 Andrew Hill <andru@src.gnome.org>
+ * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@ximian.com>
+ * Copyright (C) 2003 - 2006 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2004 Szalai Ferenc <szferi@einstein.ki.iif.hu>
+ * Copyright (C) 2005 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
  *
- * AUTHORS:
- *      Michael Lausch <michael@lausch.at>
- *	Rodrigo Moya <rodrigo@gnome-db.org>
- *	Bas Driessen <bas.driessen@xobas.com>
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #ifndef __LIBGDA_H__
@@ -35,7 +38,7 @@
 #include <libgda/gda-connection-private.h>
 #include <libgda/gda-data-comparator.h>
 #include <libgda/gda-data-model-array.h>
-#include <libgda/gda-data-model-bdb.h>
+
 #include <libgda/gda-data-model-ldap.h>
 #include <libgda/gda-tree-mgr-ldap.h>
 #include <libgda/gda-data-model.h>
